@@ -173,3 +173,35 @@ class TestModelFormConfiguration(ModelFormTestCase):
 
         form = ModelTestForm(MultiDict(test_column=u' something '))
         assert form.test_column.data == u'something'
+
+    def test_strip_strings_fields_with_empty_values(self):
+        self.init()
+
+        class ModelTestForm(ModelForm):
+            class Meta:
+                model = self.ModelTest
+                only = ['test_column']
+                strip_string_fields = True
+
+        form = ModelTestForm()
+
+    def test_class_meta_regression(self):
+        self.init()
+
+        class SomeForm(ModelForm):
+            class Meta:
+                model = self.ModelTest
+                foo = 9
+
+
+        class OtherForm(SomeForm):
+            class Meta:
+                pass
+
+        assert issubclass(OtherForm.Meta, SomeForm.Meta)
+        form = OtherForm()
+
+        # Create a side effect on the base meta.
+        assert form.Meta.foo == 9
+        SomeForm.Meta.foo = 12
+        assert form.Meta.foo == 12
