@@ -1,6 +1,7 @@
 #import pytz
 import six
 from wtforms import Form
+from wtforms.validators import InputRequired, DataRequired
 from wtforms.form import FormMeta
 from wtforms_components import (
     DateRange,
@@ -16,8 +17,6 @@ from .utils import (
     is_scalar,
     null_or_int,
     null_or_unicode,
-    class_list,
-    properties,
 )
 from .exc import InvalidAttributeException, UnknownTypeException
 from .fields import ModelFieldList, ModelFormField
@@ -43,7 +42,7 @@ __all__ = (
 )
 
 
-__version__ = '0.8.6'
+__version__ = '0.9.2'
 
 
 class ModelFormMeta(FormMeta):
@@ -54,12 +53,12 @@ class ModelFormMeta(FormMeta):
     ModelForm classes inherit parent's Meta class properties.
     """
     def __init__(cls, *args, **kwargs):
-        property_dict = {}
-        for class_ in reversed(class_list(cls)):
-            if hasattr(class_, 'Meta'):
-                property_dict.update(class_.Meta.__dict__)
+        bases = []
+        for class_ in cls.__mro__:
+            if 'Meta' in class_.__dict__:
+                bases.append(getattr(class_, 'Meta'))
 
-        cls.Meta = type('Meta', (object, ), property_dict)
+        cls.Meta = type('Meta', tuple(bases), {})
 
         FormMeta.__init__(cls, *args, **kwargs)
 
@@ -123,6 +122,15 @@ def model_form_factory(base=Form, meta=ModelFormMeta, **defaults):
                 'include_datetimes_with_default', False
             )
 
+            #: The default validator to be used for not nullable columns. Set
+            #: this to `None` if you wish to disable it.
+            not_null_validator = InputRequired()
+
+            #: The default validator to be used for not nullable string
+            #: columns. If this is set to `None` the configuration option
+            #: `not_null_validator` will be used for string columns also.
+            not_null_str_validator = [InputRequired(), DataRequired()]
+
             #: Which form generator to use. Only override this if you have a
             #: valid form generator which you want to use instead of the
             #: default one.
