@@ -1,7 +1,6 @@
 import six
 import sqlalchemy as sa
 from sqlalchemy import types
-from .exc import UnknownIdentityException
 
 
 def strip_string(value):
@@ -25,6 +24,16 @@ def null_or_int(value):
         return None
 
 
+def flatten(list_):
+    result = []
+    if isinstance(list_, list):
+        for value in list_:
+            result.extend(flatten(value))
+    else:
+        result.append(list_)
+    return result
+
+
 def is_numerical_column(column):
     return (
         is_integer_column(column) or
@@ -48,20 +57,6 @@ def is_date_column(column):
     )
 
 
-def class_list(cls):
-    """Simple recursive function for listing the parent classes of given class.
-    Used by the ModelFormMeta class.
-    """
-    list_of_parents = [cls]
-    for parent in cls.__bases__:
-        list_of_parents.extend(class_list(parent))
-    return list_of_parents
-
-
-def properties(cls):
-    return dict((name, getattr(cls, name)) for name in dir(cls))
-
-
 def table(model):
     if isinstance(model, sa.schema.Table):
         return model
@@ -75,23 +70,18 @@ def primary_keys(model):
             yield column
 
 
-def has_entity(obj, name, model, data):
+def find_entity(coll, model, data):
     for column in primary_keys(model):
         if not column.name in data or not data[column.name]:
-            return False
-
-        found = False
+            return None
         coerce_func = column.type.python_type
-        for related_obj in getattr(obj, name):
+        for related_obj in coll:
             value = getattr(related_obj, column.name)
 
             try:
                 if value == coerce_func(data[column.name]):
-                    found = True
+                    return related_obj
             except ValueError:
                 # coerce failed
                 pass
-
-        if not found:
-            raise UnknownIdentityException()
-    return True
+    return None
